@@ -1,5 +1,6 @@
 // TODO Find a decent logging library?
 pub mod day1;
+pub mod day2;
 
 pub trait PuzzleSolver {
     fn part_one(&self) -> String {
@@ -27,6 +28,7 @@ pub trait PuzzleSolver {
 pub fn new_solver(day: &str, input: &str) -> Option<Box<dyn PuzzleSolver>> {
     match day {
         "1" => Some(Box::new(day1::Solver::new(input))),
+        "2" => Some(Box::new(day2::Solver::new(input))),
         _ => None,
     }
 }
